@@ -69,7 +69,7 @@ Reference
 """
 
 import numpy as np
-from guidata.utils import update_dataset
+from guidata.dataset import update_dataset
 from guidata.utils.misc import assert_interfaces_valid
 
 from guiqwt.baseplot import canvas_to_axes
