@@ -126,6 +126,9 @@ class BasePlot(QwtPlot):
     #: Signal emitted by plot when an IBasePlotItem object was moved (args: x0, y0, x1, y1)
     SIG_ITEM_MOVED = Signal(object, float, float, float, float)
 
+    #: Signal emitted by plot when an IBasePlotItem handle was moved
+    SIG_ITEM_HANDLE_MOVED = Signal(object)
+
     #: Signal emitted by plot when a shapes.Marker position changes
     SIG_MARKER_CHANGED = Signal(object)
 
@@ -609,7 +612,7 @@ class BasePlot(QwtPlot):
     def serialize(self, writer, selected=False):
         """
         Save (serializable) items to HDF5 file:
-            * writer: :py:class:`guidata.hdf5io.HDF5Writer` object
+            * writer: :py:class:`guidata.dataset.io.HDF5Writer` object
             * selected=False: if True, will save only selected items
 
         See also :py:meth:`guiqwt.baseplot.BasePlot.restore_items_from_hdf5`
@@ -624,7 +627,7 @@ class BasePlot(QwtPlot):
     def deserialize(self, reader):
         """
         Restore items from HDF5 file:
-            * reader: :py:class:`guidata.hdf5io.HDF5Reader` object
+            * reader: :py:class:`guidata.dataset.io.HDF5Reader` object
 
         See also :py:meth:`guiqwt.baseplot.BasePlot.save_items_to_hdf5`
         """
