@@ -99,7 +99,7 @@ DEFAULTS = {
         "marker/curve/text/font/family": "default",
         "marker/curve/text/font/bold": False,
         "marker/curve/text/font/italic": False,
-        "marker/curve/text/textcolor": MAIN_FG_COLOR,
+        "marker/curve/text/textcolor": "black",
         "marker/curve/text/background_color": "#ffffff",
         "marker/curve/text/background_alpha": 0.8,
         "marker/curve/line/style": "SolidLine",
@@ -114,7 +114,7 @@ DEFAULTS = {
         "marker/curve/sel_text/font/family": "default",
         "marker/curve/sel_text/font/bold": False,
         "marker/curve/sel_text/font/italic": False,
-        "marker/curve/sel_text/textcolor": MAIN_FG_COLOR,
+        "marker/curve/sel_text/textcolor": "black",
         "marker/curve/sel_text/background_color": "#ffffff",
         "marker/curve/sel_text/background_alpha": 0.8,
         "marker/curve/sel_line/style": "SolidLine",
@@ -131,7 +131,7 @@ DEFAULTS = {
         "marker/cross/text/font/size": 8,
         "marker/cross/text/font/bold": False,
         "marker/cross/text/font/italic": False,
-        "marker/cross/text/textcolor": MAIN_FG_COLOR,
+        "marker/cross/text/textcolor": "black",
         "marker/cross/text/background_color": "#ffffff",
         "marker/cross/text/background_alpha": 0.8,
         "marker/cross/line/style": "DashLine",
@@ -146,7 +146,7 @@ DEFAULTS = {
         "marker/cross/sel_text/font/size": 8,
         "marker/cross/sel_text/font/bold": False,
         "marker/cross/sel_text/font/italic": False,
-        "marker/cross/sel_text/textcolor": MAIN_FG_COLOR,
+        "marker/cross/sel_text/textcolor": "black",
         "marker/cross/sel_text/background_color": "#ffffff",
         "marker/cross/sel_text/background_alpha": 0.8,
         "marker/cross/sel_line/style": "DashLine",
@@ -163,7 +163,7 @@ DEFAULTS = {
         "marker/selectpoint/text/font/family": "default",
         "marker/selectpoint/text/font/bold": False,
         "marker/selectpoint/text/font/italic": False,
-        "marker/selectpoint/text/textcolor": MAIN_FG_COLOR,
+        "marker/selectpoint/text/textcolor": "black",
         "marker/selectpoint/text/background_color": "#ffffff",
         "marker/selectpoint/text/background_alpha": 0.8,
         "marker/selectpoint/line/style": "SolidLine",
@@ -178,7 +178,7 @@ DEFAULTS = {
         "marker/selectpoint/sel_text/font/family": "default",
         "marker/selectpoint/sel_text/font/bold": False,
         "marker/selectpoint/sel_text/font/italic": False,
-        "marker/selectpoint/sel_text/textcolor": MAIN_FG_COLOR,
+        "marker/selectpoint/sel_text/textcolor": "black",
         "marker/selectpoint/sel_text/background_color": "#ffffff",
         "marker/selectpoint/sel_text/background_alpha": 0.8,
         "marker/selectpoint/sel_line/style": "SolidLine",
