@@ -70,7 +70,7 @@ Examples
 Simple example *without* the `plot manager`:
 
 .. literalinclude:: /../guiqwt/tests/filtertest1.py
-   :start-after: SHOW
+   :start-after: guitest: show
    :end-before: Workaround for Sphinx v0.6 bug: empty 'end-before' directive
 
 Simple example *with* the `plot manager`:
@@ -80,7 +80,7 @@ complex applications, using the `plot manager` allows to design highly versatile
 graphical user interfaces.
 
 .. literalinclude:: /../guiqwt/tests/filtertest2.py
-   :start-after: SHOW
+   :start-after: guitest: show
    :end-before: Workaround for Sphinx v0.6 bug: empty 'end-before' directive
 
 Reference
@@ -121,7 +121,7 @@ from qtpy.QtCore import Qt
 from qtpy import PYQT5
 
 from guidata.configtools import get_icon
-from guidata.utils import assert_interfaces_valid
+from guidata.utils.misc import assert_interfaces_valid
 from guidata.qthelpers import create_action, win32_fix_title_bar_background
 
 # Local imports
@@ -823,12 +823,9 @@ class SubplotWidget(QSplitter):
         if height is None:
             height = self.xcsw.height() - self.ycsw.toolbar.height()
         self.ycsw.adjust_height(height)
-        if height:
-            QApplication.processEvents()
 
     def xcsw_is_visible(self, state):
         if state:
-            QApplication.processEvents()
             self.adjust_ycsw_height()
         else:
             self.adjust_ycsw_height(0)
@@ -1296,12 +1293,9 @@ class BaseImageWidget(QSplitter):
         if height is None:
             height = self.xcsw.height() - self.ycsw.toolbar.height()
         self.ycsw.adjust_height(height)
-        if height:
-            QApplication.processEvents()
 
     def xcsw_is_visible(self, state):
         if state:
-            QApplication.processEvents()
             self.adjust_ycsw_height()
         else:
             self.adjust_ycsw_height(0)
