@@ -10,12 +10,14 @@ guiqwt test package
 ===================
 """
 
+
 def run():
     """Run guiqwt test launcher"""
-    import guiqwt.config # Loading icons
+    import guiqwt.config  # Loading icons
     from guidata.guitest import run_testlauncher
+
     run_testlauncher(guiqwt)
 
-if __name__ == '__main__':
+
+if __name__ == "__main__":
     run()
-    
\ No newline at end of file
