@@ -7,7 +7,7 @@
 
 """All image and plot tools test"""
 
-SHOW = True  # Show test in GUI-based test launcher
+# guitest: show
 
 import os.path as osp
 
