@@ -7,12 +7,12 @@
 
 """Load/save items from/to HDF5 file"""
 
-SHOW = True  # Show test in GUI-based test launcher
+# guitest: show
 
 # WARNING:
 # This script requires read/write permissions on current directory
 
-from guidata.hdf5io import HDF5Reader, HDF5Writer
+from guidata.dataset.io import HDF5Reader, HDF5Writer
 
 from guiqwt.tests.loadsaveitems_pickle import IOTest
 
