@@ -25,9 +25,9 @@ import os.path as osp
 
 from guiqwt.tests.loadsaveitems_pickle import IOTest
 
-from guidata.jsonio import JSONReader, JSONWriter
+from guidata.dataset.io import JSONReader, JSONWriter
 
-SHOW = True  # Show test in GUI-based test launcher
+# guitest: show
 
 
 class JSONTest(IOTest):
