@@ -7,7 +7,7 @@
 
 """Mandelbrot demo"""
 
-SHOW = True  # Show test in GUI-based test launcher
+# guitest: show
 
 import numpy as np
 
