@@ -8,7 +8,7 @@
 """ImageDialog / Pcolor test"""
 
 
-SHOW = True  # Show test in GUI-based test launcher
+# guitest: show
 
 import numpy as np
 
