@@ -7,7 +7,7 @@
 
 """CurveDialog test"""
 
-SHOW = True  # Show test in GUI-based test launcher
+# guitest: show
 
 from qtpy.QtGui import QFont
 
